myexperiment-hackers
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[myexperiment-hackers] [2116] trunk: new conf module, including configur


From: noreply
Subject: [myexperiment-hackers] [2116] trunk: new conf module, including configurable site name, logo and tabs
Date: Wed, 11 Mar 2009 09:42:49 -0400 (EDT)

Revision
2116
Author
dgc
Date
2009-03-11 09:42:48 -0400 (Wed, 11 Mar 2009)

Log Message

new conf module, including configurable site name, logo and tabs

Modified Paths

Added Paths

Diff

Modified: trunk/app/controllers/application.rb (2115 => 2116)


--- trunk/app/controllers/application.rb	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/controllers/application.rb	2009-03-11 13:42:48 UTC (rev 2116)
@@ -31,7 +31,7 @@
     res = false
     
     referer = request.env['HTTP_REFERER']
-    unless referer.nil? || referer.match("^#{BASE_URI}").nil?
+    unless referer.nil? || referer.match("^#{Conf.base_uri}").nil?
       res = true
     end
     

Modified: trunk/app/controllers/messages_controller.rb (2115 => 2116)


--- trunk/app/controllers/messages_controller.rb	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/controllers/messages_controller.rb	2009-03-11 13:42:48 UTC (rev 2116)
@@ -99,7 +99,7 @@
       respond_to do |format|
         error_msg = "You can't send messages - your limit is reached, "
         if allowed_plus_timespan[1].nil?
-          error_msg += "it will not be reset. Please contact myExperiment administration for details."
+          error_msg += "it will not be reset. Please contact #{Conf.sitename} administration for details."
         elsif allowed_plus_timespan[1] <= 60
           error_msg += "please try again within a couple of minutes"
         else

Modified: trunk/app/controllers/networks_controller.rb (2115 => 2116)


--- trunk/app/controllers/networks_controller.rb	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/controllers/networks_controller.rb	2009-03-11 13:42:48 UTC (rev 2116)
@@ -37,7 +37,7 @@
       # limit of invitation for this user is already exceeded
       error_msg = "Please note that you can't send email invitations - your limit is reached, "
       if sending_allowed_with_reset_timestamp[1].nil?
-        error_msg += "it will not be reset. Please contact myExperiment administration for details."
+        error_msg += "it will not be reset. Please contact #{Conf.sitename} administration for details."
       elsif sending_allowed_with_reset_timestamp[1] <= 60
         error_msg += "please try again within a couple of minutes"
       else
@@ -195,7 +195,7 @@
             error_msg += "<br/><br/>You have ran out of quota for sending invitations, "
             reset_quota_after = ActivityLimit.check_limit(current_user, "group_invite", false)[1]
             if reset_quota_after.nil?
-              error_msg += "it will not be reset. Please contact myExperiment administration for details."
+              error_msg += "it will not be reset. Please contact #{Conf.sitename} administration for details."
             elsif reset_quota_after <= 60
               error_msg += "please try again within a couple of minutes."
             else

Modified: trunk/app/controllers/openid_controller.rb (2115 => 2116)


--- trunk/app/controllers/openid_controller.rb	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/controllers/openid_controller.rb	2009-03-11 13:42:48 UTC (rev 2116)
@@ -34,7 +34,7 @@
         if current_user.save
           redirect_to user_path(current_user)
         else
-          flash[:error] = 'OpenID already registered to another myExperiment account'
+          flash[:error] = "OpenID already registered to another #{Conf.sitename} account"
           redirect_to new_openid_url
         end
         

Modified: trunk/app/controllers/session_controller.rb (2115 => 2116)


--- trunk/app/controllers/users_controller.rb	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/controllers/users_controller.rb	2009-03-11 13:42:48 UTC (rev 2116)
@@ -8,7 +8,6 @@
   contributable_actions = [:workflows, :files, :packs, :blogs]
   show_actions = [:show, :news, :friends, :groups, :credits, :tags, :favourites] + contributable_actions
 
-  # add ', :invite' to allow displaying of invitation screen without logging in
   before_filter :login_required, :except => [:index, :new, :create, :search, :all, :confirm_email, :forgot_password, :reset_password] + show_actions
   
   before_filter :find_users, : [:all]
@@ -283,7 +282,7 @@
     
     respond_to do |format|
       if confirmed
-        flash[:notice] = "Thank you for confirming your email. Your account is now active (if it wasn't before), and the new email address registered on your account. We hope you enjoy using myExperiment!"
+        flash[:notice] = "Thank you for confirming your email. Your account is now active (if it wasn't before), and the new email address registered on your account. We hope you enjoy using #{Conf.sitename}!"
         format.html { redirect_to user_url(@user) }
       else
         flash[:error] = "Invalid confirmation URL"
@@ -373,7 +372,7 @@
         # limit of invitation for this user is already exceeded
         error_msg = "You can't send invitations - your limit is reached, "
         if sending_allowed_with_reset_timestamp[1].nil?
-          error_msg += "it will not be reset. Please contact myExperiment administration for details."
+          error_msg += "it will not be reset. Please contact #{Conf.sitename} administration for details."
         elsif sending_allowed_with_reset_timestamp[1] <= 60
           error_msg += "please try again within a couple of minutes"
         else
@@ -515,7 +514,7 @@
             error_msg += "<br/><br/>You have ran out of quota for sending invitations, "
             reset_quota_after = ActivityLimit.check_limit(current_user, "user_invite", false)[1]
             if reset_quota_after.nil?
-              error_msg += "it will not be reset. Please contact myExperiment administration for details."
+              error_msg += "it will not be reset. Please contact #{Conf.sitename} administration for details."
             elsif reset_quota_after <= 60
               error_msg += "please try again within a couple of minutes."
             else

Modified: trunk/app/helpers/application_helper.rb (2115 => 2116)


--- trunk/app/models/contribution.rb	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/models/contribution.rb	2009-03-11 13:42:48 UTC (rev 2116)
@@ -17,7 +17,7 @@
            :dependent => :destroy
            
   # returns the 'most downloaded' Contributions
-  # (only takes into account donwloads on myExperiment, that is internal usage)
+  # (only takes into account downloads, that is internal usage)
   # the maximum number of results is set by #limit#
   def self.most_downloaded(limit=10, klass=nil)
     if klass
@@ -30,7 +30,7 @@
   end
   
   # returns the 'most viewed' Contributions
-  # (only takes into account viewings on myExperiment, that is internal usage)
+  # (only takes into account viewings, that is internal usage)
   # the maximum number of results is set by #limit#
   def self.most_viewed(limit=10, klass=nil)
     if klass

Modified: trunk/app/models/mailer.rb (2115 => 2116)


--- trunk/app/models/mailer.rb	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/models/mailer.rb	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,12 +1,9 @@
 class Mailer < ActionMailer::Base
-  
-  NOTIFICATIONS_EMAIL = "address@hidden"
-  FEEDBACK_EMAIL = "address@hidden"
 
   def feedback(name, subject, content)
-    recipients FEEDBACK_EMAIL
-    from NOTIFICATIONS_EMAIL
-    subject "myExperiment feedback from #{name}"
+    recipients Conf.feedback_email_address
+    from Conf.notifications_email_address
+    subject "#{Conf.sitename} feedback from #{name}"
     
     body :name => name, 
          :subject => subject, 
@@ -15,8 +12,8 @@
   
   def account_confirmation(user, hash, base_url)
     recipients user.unconfirmed_email
-    from NOTIFICATIONS_EMAIL
-    subject "Welcome to myExperiment. Please activate your account."
+    from Conf.notifications_email_address
+    subject "Welcome to #{Conf.sitename}. Please activate your account."
 
     body :name => user.name, 
          :username => user.username, 
@@ -26,8 +23,8 @@
   
   def forgot_password(user, base_url)
     recipients user.email
-    from NOTIFICATIONS_EMAIL
-    subject "myExperiment - Reset Password Request"
+    from Conf.notifications_email_address
+    subject "#{Conf.sitename} - Reset Password Request"
 
     body :name => user.name, 
          :username => user.username, 
@@ -38,8 +35,8 @@
   
   def update_email_address(user, hash, base_url)
     recipients user.unconfirmed_email
-    from NOTIFICATIONS_EMAIL
-    subject "myExperiment - Update Email Address on Account"
+    from Conf.notifications_email_address
+    subject "#{Conf.sitename} - Update Email Address on Account"
 
     body :name => user.name, 
          :username => user.username, 
@@ -50,8 +47,8 @@
   
   def invite_new_user(user, email, msg_text, base_url)
     recipients email
-    from user.name + "<" + NOTIFICATIONS_EMAIL + ">"
-    subject "Invitation to join myExperiment.org"
+    from user.name + "<" + Conf.notifications_email_address + ">"
+    subject "Invitation to join #{Conf.sitename}"
 
     body :name => user.name, 
          :user_id => user.id, 
@@ -61,8 +58,8 @@
 
   def group_invite_new_user(user, group, email, msg_text, token, base_url)
     recipients email
-    from user.name + "<" + NOTIFICATIONS_EMAIL + ">"
-    subject "Invitation to join group \"#{group.title}\" at myExperiment.org"
+    from user.name + "<" + Conf.notifications_email_address + ">"
+    subject "Invitation to join group \"#{group.title}\" at #{Conf.sitename}"
 
     body :name => user.name, 
          :user_id => user.id,
@@ -76,8 +73,8 @@
   
   def friendship_invite_new_user(user, email, msg_text, token, base_url)
     recipients email
-    from user.name + "<" + NOTIFICATIONS_EMAIL + ">"
-    subject "Invitation to become my friend on myExperiment.org"
+    from user.name + "<" + Conf.notifications_email_address + ">"
+    subject "Invitation to become my friend on #{Conf.sitename}"
 
     body :name => user.name, 
          :user_id => user.id,

Modified: trunk/app/models/notifier.rb (2115 => 2116)


--- trunk/app/models/notifier.rb	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/models/notifier.rb	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,11 +1,9 @@
 class Notifier < ActionMailer::Base
-  
-  NOTIFICATIONS_EMAIL = "address@hidden"
 
   def friendship_request(user, friend_name, friendship, base_url)
     recipients user.email
-    from NOTIFICATIONS_EMAIL
-    subject "myExperiment - #{friend_name} has requested to be your friend"
+    from Conf.notifications_email_address
+    subject "#{Conf.sitename} - #{friend_name} has requested to be your friend"
     
     body :user => user,
          :friend_name => friend_name,
@@ -15,8 +13,8 @@
   
   def membership_invite(user, network, membership, base_url)
     recipients user.email
-    from NOTIFICATIONS_EMAIL
-    subject "myExperiment - you have been invited to join the #{network.title} Group"
+    from Conf.notifications_email_address
+    subject "#{Conf.sitename} - you have been invited to join the #{network.title} Group"
     
     body :user => user,
          :network => network,
@@ -26,8 +24,8 @@
   
   def membership_request(requestor, network, membership, base_url)
     recipients network.owner.email
-    from NOTIFICATIONS_EMAIL
-    subject "myExperiment - #{requestor.name} would like to join the #{network.title} Group"
+    from Conf.notifications_email_address
+    subject "#{Conf.sitename} - #{requestor.name} would like to join the #{network.title} Group"
     
     body :user => network.owner,
          :network => network,
@@ -38,8 +36,8 @@
   
   def auto_join_group(member, network, base_url)
     recipients network.owner.email
-    from NOTIFICATIONS_EMAIL
-    subject "myExperiment - #{member.name} has joined the #{network.title} Group"
+    from Conf.notifications_email_address
+    subject "#{Conf.sitename} - #{member.name} has joined the #{network.title} Group"
     
     body :name => network.owner.name,
          :username => network.owner.username,
@@ -50,8 +48,8 @@
   
   def new_message(message, base_url)
     recipients message.u_to.email
-    from NOTIFICATIONS_EMAIL
-    subject "myExperiment - #{message.u_from.name} has sent you a message"
+    from Conf.notifications_email_address
+    subject "#{Conf.sitename} - #{message.u_from.name} has sent you a message"
     
     body :name => message.u_to.name,
          :username => message.u_to.username,

Modified: trunk/app/models/pack.rb (2115 => 2116)


--- trunk/app/models/pack.rb	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/models/pack.rb	2009-03-11 13:42:48 UTC (rev 2116)
@@ -74,7 +74,7 @@
   end
   
   def archive_file_path(no_timestamp=false)
-    # "#{BASE_URI}/packs/#{id}/download/pack_#{id}.zip"
+    # "#{Conf.base_uri}/packs/#{id}/download/pack_#{id}.zip"
     return(Pack.archive_folder + "/" + archive_file(no_timestamp))
   end
   
@@ -117,7 +117,7 @@
     # plain-TEXT
     # generate pack description data (which will be put into a text file in the archive)
     pack_data_txt = "********** Snapshot of the Pack: #{self.title} **********\n\n"
-    pack_data_txt += "Downloaded from myExperiment.org\n"
+    pack_data_txt += "Downloaded from #{Conf.sitename}\n"
     pack_data_txt += "Snapshot generated at " + Time.now.strftime("%H:%M:%S on %A, %d %B %Y") + "\n\n\n\n"
     pack_data_txt += "========== Pack Details ==========\n\n"
     pack_data_txt += "Title: #{self.title}"
@@ -344,14 +344,14 @@
       # HTML
       pack_data_html = cgi.html{
         cgi.head{ 
-          cgi.title{"Snapshot of the Pack: #{self.title} (from myExperiment.org)"} +
+          cgi.title{"Snapshot of the Pack: #{self.title} (from #{Conf.sitename})"} +
           cgi.link("href" => "index.css", "media" => "screen", "rel" => "Stylesheet", "type" => "text/css")
         } +
         cgi.body{
           cgi.div("class" => "provider_info") do
             cgi.h1{"Snapshot of the Pack: #{cgi.a(location_string("pack", self.id)){self.title}}"} +
             cgi.p{
-              cgi.i{"Downloaded from #{cgi.a(BASE_URI){'myExperiment.org'}} website<br/><br/>" +
+              cgi.i{"Downloaded from #{cgi.a(Conf.base_uri){Conf.sitename}} website<br/><br/>" +
               "Snapshot generated at " + Time.now.strftime("%H:%M:%S on %A, %d %B %Y")} 
             }
           end +
@@ -622,16 +622,16 @@
       when "user"
         user = User.find(contributor_id)
         if html_required
-          res += "<a href=""
+          res += "<a href=""
         else
-          res += user.name + " (profile: #{BASE_URI}/users/#{contributor_id})"
+          res += user.name + " (profile: #{Conf.base_uri}/users/#{contributor_id})"
         end
       when "network"
         group = Network.find(contributor_id)
         if html_required
-          res += "<a href="" group</a>"
+          res += "<a href="" group</a>"
         else
-          res += group.title + " (profile: #{BASE_URI}/groups/#{contributor_id})"
+          res += group.title + " (profile: #{Conf.base_uri}/groups/#{contributor_id})"
         end
       else
         res += "unknown (contributor_type: #{contributor_type}; contributor_id: #{contributor_id})"
@@ -644,7 +644,7 @@
   # a helper to return the link to a resource based on type, id & version 
   # (version is NIL by default - means no version, or the latest one)
   def location_string(type, id, version=nil)
-    link = BASE_URI
+    link = Conf.base_uri
     case type.downcase
       when "workflow"; link += "/workflows/"
       when "blob";     link += "/files/"

Modified: trunk/app/models/user.rb (2115 => 2116)


--- trunk/app/models/user.rb	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/models/user.rb	2009-03-11 13:42:48 UTC (rev 2116)
@@ -269,7 +269,7 @@
   
   def admin?
     return false if self.username.blank?
-    return ADMINS.include?(self.username.downcase)
+    return Conf.admins.include?(self.username.downcase)
   end
   
   acts_as_contributor

Modified: trunk/app/models/workflow.rb (2115 => 2116)


--- trunk/app/models/workflow.rb	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/models/workflow.rb	2009-03-11 13:42:48 UTC (rev 2116)
@@ -173,7 +173,7 @@
   end
   
   def named_download_url
-    "#{BASE_URI}/workflows/#{id}/download/#{filename}"
+    "#{Conf.base_uri}/workflows/#{id}/download/#{filename}"
   end
 
   def get_all_search_terms

Modified: trunk/app/views/announcements/index.rxml (2115 => 2116)


--- trunk/app/views/announcements/index.rxml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/announcements/index.rxml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,11 +1,11 @@
 xml.rss "version" => "2.0", 'xmlns:opensearch' => "http://a9.com/-/spec/opensearch/1.1/", 'xmlns:atom' => "http://www.w3.org/2005/Atom" do
   xml.channel do
-    xml.title "myExperiment.org - Site Announcements"
+    xml.title "#{Conf.sitename} - Site Announcements"
     xml.link announcements_url
     xml.language "en-us"
     xml.ttl "60"
     xml.tag! "atom:link", :rel => 'search', :type => 'application/opensearchdescription+xml', :href ="" "http://#{request.host_with_port}/open_search.xml"
-    xml.description "RSS feed listing the Announcements on myExperiment.org"
+    xml.description "RSS feed listing the Announcements on #{Conf.sitename}"
     render(:partial => "layouts/announcement", :collection => @announcements, :locals => { :xm => xml })
   end
-end
\ No newline at end of file
+end

Modified: trunk/app/views/blobs/_license.rhtml (2115 => 2116)


--- trunk/app/views/blobs/_license.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/blobs/_license.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -16,7 +16,7 @@
       <dc:title><%= contributor(blob.contribution.contributor_id, blob.contribution.contributor_type, link=false) %></dc:title>
    </Agent></dc:rights>
    <dc:type rdf:resource="http://purl.org/dc/dcmitype/Data" />
-   <dc:source rdf:resource="http://www.myexperiment.org<%= request.request_uri %>"/>
+   <dc:source rdf:resource="<%= Conf.base_uri %><%= request.request_uri %>"/>
    <license rdf:resource="http://creativecommons.org/licenses/by-nd/3.0/" />
 </Work>
 
@@ -50,7 +50,7 @@
       <dc:title><%= contributor(blob.contribution.contributor_id, blob.contribution.contributor_type, link=false) %></dc:title>
    </Agent></dc:rights>
    <dc:type rdf:resource="http://purl.org/dc/dcmitype/Data" />
-   <dc:source rdf:resource="http://www.myexperiment.org<%= request.request_uri %>"/>
+   <dc:source rdf:resource="<%= Conf.base_uri %><%= request.request_uri %>"/>
    <license rdf:resource="http://creativecommons.org/licenses/by-sa/3.0/" />
 </Work>
 
@@ -85,7 +85,7 @@
       <dc:title><%= contributor(blob.contribution.contributor_id, blob.contribution.contributor_type, link=false) %></dc:title>
    </Agent></dc:rights>
    <dc:type rdf:resource="http://purl.org/dc/dcmitype/Data" />
-   <dc:source rdf:resource="http://www.myexperiment.org<%= request.request_uri %>"/>
+   <dc:source rdf:resource="<%= Conf.base_uri %><%= request.request_uri %>"/>
    <license rdf:resource="http://creativecommons.org/licenses/by/3.0/" />
 </Work>
 
@@ -105,4 +105,4 @@
 
 <p>
   All versions of this File are licensed under the <%= license_link blob.license.to_s %>.
-</p>
\ No newline at end of file
+</p>

Modified: trunk/app/views/contributions/_credit_attribution_form.rhtml (2115 => 2116)


--- trunk/app/views/contributions/_credit_attribution_form.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/contributions/_credit_attribution_form.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -65,7 +65,7 @@
 				<p>
             <label for="" id="author_option_3" name="add_author_option"
                 value="3" type="radio"  />
-            - A user on myExperiment who is not a Friend.</label>
+            - A user on <%= Conf.sitename %> who is not a Friend.</label>
         </p>
         <div id="author_otheruser_box" style="display: none; padding-left: 2em;">
             <p>
@@ -80,7 +80,7 @@
 				<p>
             <label for="" id="author_option_4" name="add_author_option"
                 value="4" type="radio"  />
-            - A myExperiment Group</label>
+            - A <%= Conf.sitename %> Group</label>
         </p>
         <div id="author_networks_box" style="display: none; padding-left: 2em;">
             <p>
@@ -135,7 +135,7 @@
       </p>
       <div style="font-size: 93%; margin-top: 1em;">
         <div class="box_simple" style="float: left; text-align: left; width: 300px;">
-          Existing Workflows on myExperiment:
+          Existing Workflows on <%= Conf.sitename %>:
           <br />
           <br />
           <select id="existingworkflows_dropdown" style="width: 280px;">
@@ -149,7 +149,7 @@
         </div>
 	
         <div class="box_simple" style="float: left; margin-left: 1em; text-align: left; width: 300px;">
-          Existing Files on myExperiment:
+          Existing Files on <%= Conf.sitename %>:
           <br />
           <br />
           <select id="existingfiles_dropdown" style="width: 280px;">
@@ -224,4 +224,4 @@
     <% end %>
     updateAttributionsList();
   </script>
-<% end %>
\ No newline at end of file
+<% end %>

Modified: trunk/app/views/contributions/_sharing_form.rhtml (2115 => 2116)


--- trunk/app/views/contributions/_sharing_form.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/contributions/_sharing_form.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -10,7 +10,7 @@
 <div class="fold">
 
   <div class="foldTitle">
-    <%= info_icon_with_tooltip("Here you can specify who can <b>view</b> and <b>download</b> this #{c_type} on myExperiment. <br/><br/>You can also set <b>update</b> permissions for this #{c_type}. <br/><br/>You can also explicitly share this #{c_type} with your Groups.<br/><br/>By default, anyone can view, but only Friends can download; #{if update_perms then 'no one is allowed to update; ' end}and not shared with any Groups.") %>
+    <%= info_icon_with_tooltip("Here you can specify who can <b>view</b> and <b>download</b> this #{c_type} on #{Conf.sitename}. <br/><br/>You can also set <b>update</b> permissions for this #{c_type}. <br/><br/>You can also explicitly share this #{c_type} with your Groups.<br/><br/>By default, anyone can view, but only Friends can download; #{if update_perms then 'no one is allowed to update; ' end}and not shared with any Groups.") %>
     Sharing
 	<% if edit %>
 		<hr/>
@@ -25,7 +25,7 @@
 
     <div class="box_infotext">
     	<p>
-    		Here you can specify who can <b>view</b> and <b>download</b> this <%= c_type %> on myExperiment.
+    		Here you can specify who can <b>view</b> and <b>download</b> this <%= c_type %> on <%= Conf.sitename %>.
 			</p>
 			
 			<% if update_perms -%>
@@ -46,7 +46,7 @@
 		<br/>
 		
 		<!-- View/Download Permissions -->
-    <p><strong>Who can view and download this <%= c_type %> on myExperiment?</strong></p>
+    <p><strong>Who can view and download this <%= c_type %> on <%= Conf.sitename %>?</strong></p>
 
 		<div class="box_editing" style="padding-left: 1em; font-size: 93%;">
 
@@ -93,7 +93,7 @@
 			<br/>
 			
 			<!-- Update Permissions -->
-			<p><strong>Who can update this <%= c_type %> on myExperiment?</strong></p>
+			<p><strong>Who can update this <%= c_type %> on <%= Conf.sitename %>?</strong></p>
 	
 			<div class="box_editing" style="padding-left: 1em; font-size: 93%;">
 				<p style="color: #666666;">

Modified: trunk/app/views/contributions/_statistics_detailed.rhtml (2115 => 2116)


--- trunk/app/views/contributions/_statistics_detailed.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/contributions/_statistics_detailed.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -42,8 +42,8 @@
 	    </tr>
 			<tr>
 				<td style="text-align: left; vertical-align: top;">
-					From myExperiment: <b><%= site_viewings -%></b>
-					<%= info_icon_with_tooltip("Viewings made by following links to this #{contributable_display_type} from myExperiment website.") -%>
+					From <%= Conf.sitename %>: <b><%= site_viewings -%></b>
+					<%= info_icon_with_tooltip("Viewings made by following links to this #{contributable_display_type} from the #{Conf.sitename} website.") -%>
 					<ul style="margin-top: 0.3em; margin-bottom: 0em;">
 						<li>
 							Members: <b><%= internal_member_viewings -%></b>
@@ -54,8 +54,8 @@
 					</ul>
 				</td>
 				<td style="text-align: left; vertical-align: top; padding-left: 3em;">
-					From myExperiment: <b><%= site_downloads -%></b>
-					<%= info_icon_with_tooltip("Downloads made by following links to this #{contributable_display_type} from myExperiment website.") -%>
+					From <%= Conf.sitename %>: <b><%= site_downloads -%></b>
+					<%= info_icon_with_tooltip("Downloads made by following links to this #{contributable_display_type} from the #{Conf.sitename} website.") -%>
 					<ul style="margin-top: 0.3em; margin-bottom: 0em;">
 						<li>
 							Members: <b><%= internal_member_downloads -%></b>

Modified: trunk/app/views/contributions/_terms_and_conditions.rhtml (2115 => 2116)


--- trunk/app/views/contributions/_terms_and_conditions.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/contributions/_terms_and_conditions.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -3,6 +3,6 @@
 	You are responsible for any content that you upload. 
 	You may remove your content at any time. We may make copies for operational purposes. 
 	This service is governed by the <%= link_to "JANET Acceptable Use Policy", "http://www.ja.net/services/publications/policy/aup.html", :target => "_blank" %>. 
-	Takedown requests will be reviewed by the myExperiment Management Committee. 
+	Takedown requests will be reviewed by the <%= Conf.sitename %> Management Committee. 
 	The sharing functionality is under beta test. Please contact us for further information about Terms and Conditions.
-</p>
\ No newline at end of file
+</p>

Modified: trunk/app/views/contributions/_uploader_box.rhtml (2115 => 2116)


--- trunk/app/views/contributions/_uploader_box.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/contributions/_uploader_box.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,6 +1,6 @@
 <div class="contribution_section_box">
 	<p class="heading">
-		<%= info_icon_with_tooltip("The #{owner_text contributable} is the person who uploaded/created this #{visible_name contributable} on myExperiment, and who manages it on myExperiment.") %>
+		<%= info_icon_with_tooltip("The #{owner_text contributable} is the person who uploaded/created this #{visible_name contributable} on #{Conf.sitename}, and who manages it on #{Conf.sitename}.") %>
 		<%= owner_text contributable -%>
 	</p>
 	<p>
@@ -8,4 +8,4 @@
 			<%= contributor(contributable.contribution.contributor_id, contributable.contribution.contributor_type, true, 60) %>
 		</center>
 	</p>
-</div>
\ No newline at end of file
+</div>

Modified: trunk/app/views/feedback/index.rhtml (2115 => 2116)


--- trunk/app/views/feedback/index.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/feedback/index.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -2,7 +2,7 @@
 
 <p style="text-align: center;">
 	Fill in the form below and submit, or alternatively you can email:
-	<b><%= mail_to "address@hidden", nil, { :subject => "myExperiment Feedback", :encode => "hex" } %></b>
+	<b><%= mail_to "#{Conf.feedback_email_address}", nil, { :subject => "#{Conf.sitename} Feedback", :encode => "hex" } %></b>
 </p>
 
 <p style="text-align: center;">
@@ -10,7 +10,7 @@
 </p>
 
 <div id="feedback_help" class="box_standout" style="display: none; font-size: 93%;">
-	<p>We would really appreciate feedback on your experiences with myExperiment, especially in the following areas:</p>
+	<p>We would really appreciate feedback on your experiences with <%= Conf.sitename %>, especially in the following areas:</p>
 	<ul>
 	  <li><b>User Interface:</b>  
 	    <ul>
@@ -26,7 +26,7 @@
 	  </li>
 	  <li><b>Feature Requests:</b>
 	    <ul>
-	      <li>Are there any new features that you would like to see on myExperiment? Tell us about them and we will see if we can implement them for you.</li>
+	      <li>Are there any new features that you would like to see on <%= Conf.sitename %>? Tell us about them and we will see if we can implement them for you.</li>
 	    </ul>
 	  </li>
 	</ul>

Modified: trunk/app/views/friendships/index.rhtml (2115 => 2116)


--- trunk/app/views/friendships/index.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/friendships/index.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -10,7 +10,7 @@
         You have <%=pluralize @user.friendships_pending.length, "friendship request" %> to review!
       </p>
     
-      <p>Messages sent by myExperiment users to request friendship with you are listed here.</p>
+      <p>Messages sent by <%= Conf.sitename %> users to request friendship with you are listed here.</p>
     
       <%= render :partial => "friendships/table", :locals => { :collection => @user.friendships_pending, :friend => false } %>
     <% end %>
@@ -64,4 +64,4 @@
 
   <br/>
 
-<% end %>
\ No newline at end of file
+<% end %>

Modified: trunk/app/views/group_announcements/index.rxml (2115 => 2116)


--- trunk/app/views/group_announcements/index.rxml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/group_announcements/index.rxml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,12 +1,12 @@
 xml.rss "version" => "2.0", 'xmlns:opensearch' => "http://a9.com/-/spec/opensearch/1.1/", 'xmlns:atom' => "http://www.w3.org/2005/Atom" do
   xml.channel do
-    xml.title "myExperiment.org - Public Group Announcements for address@hidden Group"
+    xml.title "#{Conf.sitename} - Public Group Announcements for address@hidden Group"
     xml.link group_announcements_url(@group)
     xml.language "en-us"
     xml.ttl "60"
     xml.tag! "atom:link", :rel => 'search', :type => 'application/opensearchdescription+xml', :href ="" "http://#{request.host_with_port}/open_search.xml"
-    xml.description "RSS feed listing the Group Announcements for address@hidden Group on myExperiment.org"
+    xml.description "RSS feed listing the Group Announcements for address@hidden Group on #{Conf.sitename}"
     # for the feeds always display only the public announcements
     render(:partial => "layouts/group_announcement", :collection => @group.announcements_public, :locals => { :xm => xml, :group => @group })
   end
-end
\ No newline at end of file
+end

Modified: trunk/app/views/home/_stats.rhtml (2115 => 2116)


--- trunk/app/views/home/_stats.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/home/_stats.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,8 +1,8 @@
 <div class="stats">
-	myExperiment currently has
+	<%= Conf.sitename %> currently has
 	<%= link_to pluralize(User.count(:conditions => "users.activated_at IS NOT NULL"), "user"), users_url -%>,
 	<%= link_to pluralize(Network.count, "group"), groups_url -%>,
 	<%= link_to pluralize(Workflow.count, "workflow"), workflows_url -%>,
 	<%= link_to pluralize(Blob.count, "file"), files_url -%> and
 	<%= link_to pluralize(Pack.count, "pack"), packs_url -%>
-</div>
\ No newline at end of file
+</div>

Modified: trunk/app/views/layouts/_feed_link_tags.rhtml (2115 => 2116)


--- trunk/app/views/layouts/_feed_link_tags.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/layouts/_feed_link_tags.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,11 +1,11 @@
 <% if controller.controller_name.to_s == "workflows" and (controller.action_name.to_s == "all" or controller.action_name.to_s == "index") -%>
-	<link href="" workflows_url %>.rss" rel="alternate" type="application/rss+xml" title="myExperiment.org - Latest Workflows" />
+	<link href="" workflows_url %>.rss" rel="alternate" type="application/rss+xml" title="<%= Conf.sitename %> - Latest Workflows" />
 <% end -%>
 
 <% if controller.controller_name.to_s == "home" or (controller.controller_name.to_s == "announcements" and controller.action_name.to_s == "index") -%>
-	<link href="" announcements_url %>.rss" rel="alternate" type="application/rss+xml" title="myExperiment.org - Site Announcements" />
+	<link href="" announcements_url %>.rss" rel="alternate" type="application/rss+xml" title="<%= Conf.sitename %> - Site Announcements" />
 <% end -%>
 
 <% if controller.controller_name.to_s == "packs" and controller.action_name.to_s == "show" -%>
-	<link href="" formatted_items_pack_path(@pack, :rss) -%>" rel="alternate" type="application/rss+xml" title="myExperiment.org - Pack items feed" />
-<% end -%>
\ No newline at end of file
+	<link href="" formatted_items_pack_path(@pack, :rss) -%>" rel="alternate" type="application/rss+xml" title="<%= Conf.sitename %> - Pack items feed" />
+<% end -%>

Modified: trunk/app/views/layouts/_footer.rhtml (2115 => 2116)


--- trunk/app/views/layouts/_footer.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/layouts/_footer.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -21,7 +21,7 @@
 				<p><%= link_to "Taverna Workflow Workbench", "http://www.taverna.org.uk/", :target => '_blank' %></p>
 				<p><%= link_to "Google Coop Search", "/google", :target => '_blank' %></p>
 				<br/>
-				<p><%= link_to "Invite people to myExperiment", invite_users_path %></p>
+				<p><%= link_to "Invite people to #{Conf.sitename}", invite_users_path %></p>
 			</td>
 			<td class="middle">
 				<p><%= link_to "myGrid", "http://www.mygrid.org.uk", :target => '_blank' %></p>

Modified: trunk/app/views/layouts/application.rhtml (2115 => 2116)


--- trunk/app/views/layouts/application.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/layouts/application.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -4,7 +4,7 @@
 <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
 	<head>
 		<meta http-equiv="content-type" content="text/html;charset=UTF-8" />
-		<%= t :site => "myExperiment.org &#45; #{controller_visible_name(controller.controller_name.humanize)}", :separator => "&#45;" %>
+		<%= t :site => "#{Conf.sitename} &#45; #{controller_visible_name(controller.controller_name.humanize)}", :separator => "&#45;" %>
 		<link rel="shortcut icon" href="" type="image/x-icon"/>
 		<%= stylesheet_link_tag 'reset-fonts-grids' %>
 		<%= stylesheet_link_tag 'base-min' %>
@@ -27,7 +27,7 @@
 			<div id="hd">
 	  			<div id="myexp_header">
 	  				<div class="logo">
-						<%= link_to image_tag("logo.png"), "/" %>
+						<%= link_to image_tag(Conf.site_logo), "/" %>
 					</div>
 					<div class="links">
 						<div style="text-align: left; float: left; width: 34%; padding-top: 6px;">
@@ -56,30 +56,11 @@
 				</div>
 				<div>
 					<ul class="tabnav">
-						<!-- Home tab -->
-						<li <%= (["home"].include?(controller.controller_name.to_s) ? ' id="selected_tabnav"' : '') %>>
-							<%= link_to "Home", home_url -%>
-						</li>
-						<!-- Users tab -->
-					  <li <%= (["users", "profiles", "userhistory", "friendships", "memberships", "pictures"].include?(controller.controller_name.to_s) ? ' id="selected_tabnav"' : '') -%>>
-							<%= link_to "Users", users_path %>
-					  </li>
-						<!-- Groups tab -->
-					  <li <%= (["networks"].include?(controller.controller_name.to_s) ? ' id="selected_tabnav"' : '') %>>
-					  	<%= link_to "Groups", groups_path -%>
-						</li>
-						<!-- Workflows tab -->
-					  <li <%= (["workflows"].include?(controller.controller_name.to_s) ? ' id="selected_tabnav"' : '') %>>
-					  	<%= link_to "Workflows", workflows_path -%>
-						</li>
-						<!-- Files tab -->
-					  <li <%= (["blobs"].include?(controller.controller_name.to_s) ? ' id="selected_tabnav"' : '') %>>
-					  	<%= link_to "Files", files_path -%>
-						</li>
-						<!-- Packs tab -->
-						<li <%= (["packs"].include?(controller.controller_name.to_s) ? ' id="selected_tabnav"' : '') %>>
-							<%= link_to("Packs", packs_path) -%>
-						</li>
+                                          <% Conf.main_tabs.each do |tab| %>
+                                            <li <%= (tab['controller'] && controller.controller_name.match(tab['controller'])) ? 'id="selected_tabnav"' : '' %>>
+                                              <%= link_to(tab['label'], tab['link']) -%>
+                                            </li>
+                                          <% end %>
 					</ul>
 				</div>
 	  			<div id="myexp_searchbar"><%= render :partial => "layouts/search" %></div>

Modified: trunk/app/views/mailer/account_confirmation.rhtml (2115 => 2116)


--- trunk/app/views/mailer/account_confirmation.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/mailer/account_confirmation.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,6 +1,6 @@
 Hi <%= @name %>,
  
-Thank you for registering with myExperiment. 
+Thank you for registering with <%= Conf.sitename %>. 
 
 Your username is: <%= @username %>
 
@@ -12,5 +12,5 @@
 						:action ="" 'confirm_email',
 						:hash => @hash %>
  
-- The myExperiment Team
-<%= BASE_URI -%>
\ No newline at end of file
+- The <%= Conf.sitename %> Team
+<%= Conf.base_uri -%>

Modified: trunk/app/views/mailer/feedback.rhtml (2115 => 2116)


--- trunk/app/views/mailer/feedback.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/mailer/feedback.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,4 +1,4 @@
-myExperiment feedback from: <%= white_list @name %>
+<%= Conf.sitename %> feedback from: <%= white_list @name %>
 
 Subject: <%= white_list @subject %>
 

Modified: trunk/app/views/mailer/forgot_password.rhtml (2115 => 2116)


--- trunk/app/views/mailer/forgot_password.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/mailer/forgot_password.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -14,5 +14,5 @@
 						
 Note: this is only valid for the next 24 hours.
  
-- The myExperiment Team
-<%= BASE_URI -%>
\ No newline at end of file
+- The <%= Conf.sitename %> Team
+<%= Conf.base_uri -%>

Modified: trunk/app/views/mailer/friendship_invite_new_user.rhtml (2115 => 2116)


--- trunk/app/views/mailer/friendship_invite_new_user.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/mailer/friendship_invite_new_user.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,6 +1,6 @@
 Greetings from <%= @name -%>,
  
-I would like to invite you to become my friend on myExperiment.org - 
+I would like to invite you to become my friend on <%= Conf.sitename %>.org - 
 the Virtual Research Environment that enables scientists to share digital items associated with their research.
 In particular it enables you to share and execute scientific workflows, to upload & share files, to create packs
 of things, and to send messages to fellow researchers.
@@ -18,7 +18,7 @@
 
 To become my friend you will have to follow these simple steps:
 
-1. Register for a myExperiment account at: <%= url_for : false, :host => @base_url, :controller => 'users', :action ="" 'new', :token => @token %>
+1. Register for a <%= Conf.sitename %> account at: <%= url_for : false, :host => @base_url, :controller => 'users', :action ="" 'new', :token => @token %>
 2. Confirm your email address as instructed during the registration process.
 3. Accept my friendship request that you will receive directly to your account once the registration is complete.
 
@@ -27,4 +27,4 @@
 
 
 Best regards,
-<%= @name -%>
\ No newline at end of file
+<%= @name -%>

Modified: trunk/app/views/mailer/group_invite_new_user.rhtml (2115 => 2116)


--- trunk/app/views/mailer/group_invite_new_user.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/mailer/group_invite_new_user.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,6 +1,6 @@
 Greetings from <%= @name -%>,
  
-I would like to invite you to join the "<%= @group_title -%>" group at myExperiment.org - 
+I would like to invite you to join the "<%= @group_title -%>" group at <%= Conf.sitename %> - 
 the Virtual Research Environment that enables scientists to share digital items associated with their research.
 In particular it enables you to share and execute scientific workflows, to upload & share files, to create packs
 of things, and to send messages to fellow researchers.
@@ -20,7 +20,7 @@
 
 To join the group you will have to follow these simple steps:
 
-1. Register for a myExperiment account at: <%= url_for : false, :host => @base_url, :controller => 'users', :action ="" 'new', :token => @token %>
+1. Register for a <%= Conf.sitename %> account at: <%= url_for : false, :host => @base_url, :controller => 'users', :action ="" 'new', :token => @token %>
 2. Confirm your email address as instructed during the registration process.
 3. Accept the group membership request that you will receive directly to your account once the registration is complete.
 
@@ -29,4 +29,4 @@
 
 
 Best regards,
-<%= @name -%>
\ No newline at end of file
+<%= @name -%>

Modified: trunk/app/views/mailer/invite_new_user.rhtml (2115 => 2116)


--- trunk/app/views/mailer/invite_new_user.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/mailer/invite_new_user.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,6 +1,6 @@
 Greetings from <%= @name -%>,
  
-I would like to invite you to join myExperiment.org - the Virtual Research Environment that enables scientists 
+I would like to invite you to join <%= Conf.sitename %> - the Virtual Research Environment that enables scientists 
 to share digital items associated with their research. In particular it enables you to share and execute scientific 
 workflows, to upload & share files, to create packs of things, and to send messages to fellow researchers.
 
@@ -19,4 +19,4 @@
 
 
 Best regards,
-<%= @name -%>
\ No newline at end of file
+<%= @name -%>

Modified: trunk/app/views/mailer/update_email_address.rhtml (2115 => 2116)


--- trunk/app/views/mailer/update_email_address.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/mailer/update_email_address.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,6 +1,6 @@
 Hi <%= @name %>,
  
-You have requested to update your email address on myExperiment to: <%= @email %>
+You have requested to update your email address on <%= Conf.sitename %> to: <%= @email %>
 
 Username: <%= @username %>
 
@@ -12,5 +12,5 @@
 						:action ="" 'confirm_email',
 						:hash => @hash %>
  
-- The myExperiment Team
-<%= BASE_URI -%>
\ No newline at end of file
+- The <%= Conf.sitename %> Team
+<%= Conf.base_uri -%>

Modified: trunk/app/views/mashup/api.rhtml (2115 => 2116)


--- trunk/app/views/mashup/api.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/mashup/api.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -242,7 +242,7 @@
 <!--
 <h2 id="rest-uris">REST URIs</h2>
 
-<p>URIs used within the API refer to the myExperiment records.  In addition to
+<p>URIs used within the API refer to the <%= Conf.sitename %> records.  In addition to
 these, "REST URIs" can be requested within each API response by including 
 <tt>rest_uris=yes</tt> in the query.</p>
 

Modified: trunk/app/views/networks/_form.rhtml (2115 => 2116)


--- trunk/app/views/networks/_form.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/networks/_form.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -17,7 +17,7 @@
     <legend>Persistent URL</legend>
     <p>What is a <%= link_to 'pURL', "http://en.wikipedia.org/wiki/Persistent_Uniform_Resource_Locator", :popup => true %>?</p>
     <p>
-      If you set a unique identifier, it will be used in future versions of myExperiment to provide a persistent and human-readable URL for your Group.
+      If you set a unique identifier, it will be used in future versions of <%= Conf.sitename %> to provide a persistent and human-readable URL for your Group.
     </p> 
     
     <p><b>Reserve yours now!</b></p>
@@ -46,4 +46,4 @@
 	</p>
 	<%= fckeditor_textarea(:network, :description, :toolbarSet => 'Simple', :width => '700px', :height => '300px') %>
 
- 
\ No newline at end of file
+ 

Modified: trunk/app/views/networks/_owner_box.rhtml (2115 => 2116)


--- trunk/app/views/networks/_owner_box.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/networks/_owner_box.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,6 +1,6 @@
 <div class="contribution_section_box">
 	<p class="heading">
-		<%= info_icon_with_tooltip("The administrator is the person who manages this group on myExperiment (which means they allow/reject/invite other users).") %>
+		<%= info_icon_with_tooltip("The administrator is the person who manages this group on #{Conf.sitename} (which means they allow/reject/invite other users).") %>
 		Administrator
 	</p>
 	<p>
@@ -8,4 +8,4 @@
 	  	<%= render :partial => "users/avatar", :locals => { :user => network.owner, :size => 60 } %>
 		</center>
 	</p>
-</div>
\ No newline at end of file
+</div>

Modified: trunk/app/views/networks/invite.rhtml (2115 => 2116)


--- trunk/app/views/networks/invite.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/networks/invite.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -8,15 +8,15 @@
 <% # on first load, has default value -%>
 <% invite_existing_selected = invite_existing_selected?(params[:radio_choice]) -%>
 
-<label for="" radio_button_tag ("radio_invite", "existing", invite_existing_selected, : "$('radio_invite_new').checked=false;$('div_invite_existing').show();$('div_invite_new').hide();return true;" ) -%>Invite an existing myExperiment user to your group</label><br/>
-<label for="" style="margin-top: 0.3em;"><%= radio_button_tag ("radio_invite", "new", !invite_existing_selected, : "$('radio_invite_existing').checked=false;$('div_invite_existing').hide();$('div_invite_new').show();return true;" ) -%>Invite someone to join myExperiment and your group</label>
+<label for="" radio_button_tag ("radio_invite", "existing", invite_existing_selected, : "$('radio_invite_new').checked=false;$('div_invite_existing').show();$('div_invite_new').hide();return true;" ) -%>Invite an existing <%= Conf.sitename %> user to your group</label><br/>
+<label for="" style="margin-top: 0.3em;"><%= radio_button_tag ("radio_invite", "new", !invite_existing_selected, : "$('radio_invite_existing').checked=false;$('div_invite_existing').hide();$('div_invite_new').show();return true;" ) -%>Invite someone to join <%= Conf.sitename %> and your group</label>
 
 <% # just one from the two of following DIVs will be shown at any one time; -%>
 <% # this represents one of two options - either to invite existing or new users to the group -%>
 
 <div id="div_invite_existing" class="box_editing" style="<%= !invite_existing_selected ? "display: none;" : "" -%>margin: 1em 0em 1em 0em;">
   <fieldset>
-  	<legend>Invite an existing myExperiment user to your group</legend>
+  	<legend>Invite an existing <%= Conf.sitename %> user to your group</legend>
 	  <p class="box_infotext" style="margin: 0.4em 0em 0.7em 0em" >
       Select a name from the list, type in a message to the user and click "Invite".
     </p>
@@ -43,7 +43,7 @@
 
 <div id="div_invite_new" class="box_editing" style="<%= invite_existing_selected ? "display: none;" : "" -%>margin: 1em 0em 1em 0em;">
 	<fieldset>
-  	<legend>Invite someone to join myExperiment and your group</legend>
+  	<legend>Invite someone to join <%= Conf.sitename %> and your group</legend>
 	  <p class="box_infotext" style="margin: 0.4em 0em 1em 0em" >
       Type in email addresses you want to send invitations to, personal message to new users and click "Invite".
     </p>
@@ -86,4 +86,4 @@
 		<% end %>
 		
 		</fieldset>
-</div>
\ No newline at end of file
+</div>

Modified: trunk/app/views/notifier/auto_join_group.rhtml (2115 => 2116)


--- trunk/app/views/notifier/auto_join_group.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/notifier/auto_join_group.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,6 +1,6 @@
 Hi <%= @name %>,
  
-<%= @member_name %> has joined the following Group on myExperiment, which you administrate:
+<%= @member_name %> has joined the following Group on <%= Conf.sitename %>, which you administrate:
 
 Name: <%= @network.title %>
 Administrator: <%= @network.owner.name %>
@@ -11,5 +11,5 @@
 
 Thanks,
  
-- The myExperiment Team
-<%= BASE_URI -%>
\ No newline at end of file
+- The <%= Conf.sitename %> Team
+<%= Conf.base_uri -%>

Modified: trunk/app/views/notifier/friendship_request.rhtml (2115 => 2116)


--- trunk/app/views/notifier/friendship_request.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/notifier/friendship_request.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -8,5 +8,5 @@
 
 Thanks,
  
-- The myExperiment Team
-<%= BASE_URI -%>
+- The <%= Conf.sitename %> Team
+<%= Conf.base_uri -%>

Modified: trunk/app/views/notifier/membership_invite.rhtml (2115 => 2116)


--- trunk/app/views/notifier/membership_invite.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/notifier/membership_invite.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,6 +1,6 @@
 Hi <%= @user.name %>,
  
-You have been invited to join the following Group on myExperiment:
+You have been invited to join the following Group on <%= Conf.sitename %>:
 
 Name: <%= @network.title %>
 Administrator: <%= @network.owner.name %>
@@ -11,5 +11,5 @@
 
 Thanks,
  
-- The myExperiment Team
-<%= BASE_URI -%>
\ No newline at end of file
+- The <%= Conf.sitename %> Team
+<%= Conf.base_uri -%>

Modified: trunk/app/views/notifier/membership_request.rhtml (2115 => 2116)


--- trunk/app/views/notifier/membership_request.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/notifier/membership_request.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,6 +1,6 @@
 Hi <%= @user.name %>,
  
-You have been sent a Membership Request from <%= @requestor.name %> to join the following Group on myExperiment, which you administrate:
+You have been sent a Membership Request from <%= @requestor.name %> to join the following Group on <%= Conf.sitename %>, which you administrate:
 
 Name: <%= @network.title %>
 Administrator: <%= @network.owner.name %>
@@ -11,5 +11,5 @@
 
 Thanks,
  
-- The myExperiment Team
-<%= BASE_URI -%>
+- The <%= Conf.sitename %> Team
+<%= Conf.base_uri -%>

Modified: trunk/app/views/notifier/new_message.rhtml (2115 => 2116)


--- trunk/app/views/notifier/new_message.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/notifier/new_message.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,6 +1,6 @@
 Hi <%= @name %>,
  
-<%= @from_name %> has sent you a message on myExperiment.
+<%= @from_name %> has sent you a message on <%= Conf.sitename %>.
 
 Subject: <%= @subject %>
 
@@ -11,5 +11,5 @@
 
 Thanks,
  
-- The myExperiment Team
-<%= BASE_URI -%>
\ No newline at end of file
+- The <%= Conf.sitename %> Team
+<%= Conf.base_uri -%>

Modified: trunk/app/views/packs/_add_item.rhtml (2115 => 2116)


--- trunk/app/views/packs/_add_item.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/packs/_add_item.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -11,7 +11,7 @@
 			<table class="quick_add">
 				<tr>
 					<td class="label" style="vertical-align: top; padding-bottom: 0;" rowspan=2>
-						<%= info_icon_with_tooltip("Type or paste in a link to something (either in myExperiment or elsewhere). The link will then be resolved appropriately.") -%>
+						<%= info_icon_with_tooltip("Type or paste in a link to something (either in #{Conf.sitename} or elsewhere). The link will then be resolved appropriately.") -%>
 						<b>Quick add:</b>
 						<p class="inner">(a link)</p>
 					</td>
@@ -119,4 +119,4 @@
 		</table>
 	</div>
 
-<% end -%>
\ No newline at end of file
+<% end -%>

Modified: trunk/app/views/packs/index.rhtml (2115 => 2116)


--- trunk/app/views/packs/index.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/packs/index.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -17,10 +17,10 @@
 			You do this by <font style="color: black; font-weight: bolder;">linking</font> to different things.
 		</p>
 		<p>
-			You can link to internal things (such as workflows, files and even other packs) as well as link to things outside of myExperiment.
+			You can link to internal things (such as workflows, files and even other packs) as well as link to things outside of <%= Conf.sitename %>.
 		</p>
 		<p>
-			Your packs can then be shared, tagged, discovered and discussed easily on myExperiment.
+			Your packs can then be shared, tagged, discovered and discussed easily on <%= Conf.sitename %>.
 		</p>
 		<center><%= image_tag 'packs.png' -%></center>
 	</div>

Modified: trunk/app/views/packs/items.rxml (2115 => 2116)


--- trunk/app/views/packs/items.rxml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/packs/items.rxml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -2,11 +2,11 @@
 
 xml.rss "version" => "2.0", 'xmlns:opensearch' => "http://a9.com/-/spec/opensearch/1.1/", 'xmlns:atom' => "http://www.w3.org/2005/Atom" do
   xml.channel do
-    xml.title "myExperiment.org - Pack: #{h @pack.title} - Items"
+    xml.title "#{Conf.sitename} - Pack: #{h @pack.title} - Items"
     xml.link pack_url(@pack)
     xml.language "en-us"
     xml.ttl "60"
     xml.description "RSS feed listing all the items in the pack: #{h @pack.title}."
     render(:partial => "layouts/pack_items", :locals => { :pack => @pack, :xm => xml })
   end
-end
\ No newline at end of file
+end

Modified: trunk/app/views/packs/new_item.rhtml (2115 => 2116)


--- trunk/app/views/packs/new_item.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/packs/new_item.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -10,7 +10,7 @@
 							     :loading => "Element.show('spinner')",
                    :complete => "Element.hide('spinner'); $('uri2').value = $('uri').value") do -%>
 
-	<p class="step_text">1. Type or paste in a link to something (on myExperiment or elsewhere) and (optionally) check it...</p>
+	<p class="step_text">1. Type or paste in a link to something (on <%= Conf.sitename %> or elsewhere) and (optionally) check it...</p>
 	
 	<center>
 		<div class="box_form" style="width: 550px; text-align: center;">
@@ -57,4 +57,4 @@
 		<input name="commit" id="commit_edit"  = $('uri').value;this.form.submit();" type="submit" value="Add the item then add more metadata" />
   </center>
 
-<% end -%>
\ No newline at end of file
+<% end -%>

Modified: trunk/app/views/runners/_status.rhtml (2115 => 2116)


--- trunk/app/views/runners/_status.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/runners/_status.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,5 +1,5 @@
 <% if service_valid -%>
-	myExperiment successfully connected to and verified the service specified by this Runner.
+	<%= Conf.sitename %> successfully connected to and verified the service specified by this Runner.
 <% else -%>
-	myExperiment was unable to connect to and verify the service specified by this Runner.
-<% end -%>
\ No newline at end of file
+	<%= Conf.sitename %> was unable to connect to and verify the service specified by this Runner.
+<% end -%>

Modified: trunk/app/views/tags/_tags_box.rhtml (2115 => 2116)


--- trunk/app/views/tags/_tags_box.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/tags/_tags_box.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,6 +1,6 @@
 <div class="contribution_section_box">
 	<p class="heading">
-		<%= info_icon_with_tooltip("The tags for this #{visible_name taggable} entry.<br/>Note(1): if this #{visible_name taggable} has many versions, the tags apply to ALL versions in this entry.<br/>Note(2): the size of the tags show how popular they are on myExperiment.") %>
+		<%= info_icon_with_tooltip("The tags for this #{visible_name taggable} entry.<br/>Note(1): if this #{visible_name taggable} has many versions, the tags apply to ALL versions in this entry.<br/>Note(2): the size of the tags show how popular they are on #{Conf.sitename}.") %>
 		Tags <span id="tags_box_header_tag_count_span" class="count_text">(<%= taggable.tags.uniq.length -%>)</span>
 		<a name="tags"></a>
 	</p>
@@ -37,4 +37,4 @@
 	<% else %>
 		<p><small><b><%= link_to "Log in", new_session_url -%></b> to add Tags</small></p>
 	<% end %>
-</div>
\ No newline at end of file
+</div>

Modified: trunk/app/views/tags/_tags_form.rhtml (2115 => 2116)


--- trunk/app/views/tags/_tags_form.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/tags/_tags_form.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -58,7 +58,7 @@
 	    </div>
 
 	    <div class="box_simple" style="font-size: 93%; text-align: left; margin-top: 1em; line-height: 1.4em;">
-	      <p>Add from your existing tags in myExperiment (click on tag to add):</p>                            
+	      <p>Add from your existing tags in <%= Conf.sitename %> (click on tag to add):</p>                            
 	      <div style="padding: 0 1em;">
 		    <% unless (tags = current_user.tags.sort {|a,b| a.name.downcase <=> b.name.downcase }).empty? %>
 					<% tags.each do |t| %>

Modified: trunk/app/views/tags/index.rhtml (2115 => 2116)


--- trunk/app/views/tags/index.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/tags/index.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,3 +1,3 @@
-<h1>All Tags on myExperiment</h1>
+<h1>All Tags on <%= Conf.sitename %></h1>
 
-<%= tag_cloud_from_collection(@tags) %>
\ No newline at end of file
+<%= tag_cloud_from_collection(@tags) %>

Modified: trunk/app/views/users/_invite.rhtml (2115 => 2116)


--- trunk/app/views/users/_invite.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/users/_invite.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,7 +1,7 @@
-<h1 style="margin-top: 2em;">Invite other people to myExperiment</h1>
+<h1 style="margin-top: 2em;">Invite other people to <%= Conf.sitename %></h1>
 
 <div class="box_infotext" style="margin: 1.5em 1.5em; text-align: center;">
-   Send invitations to people who are not already on myExperiment. You can include a message to intoduce yourself if you like.
+   Send invitations to people who are not already on <%= Conf.sitename %>. You can include a message to intoduce yourself if you like.
 </div>
 
 <% form_tag (:controller => 'users', :action ="" 'process_invitations') do %>
@@ -20,7 +20,7 @@
 		<%= text_area_tag "invitations[msg_text]", msg_text_val, :rows => 4, :style => "width: 500px; margin-bottom: 0.5em;" -%><br/>
 	  
 		<% as_friendship_checked = (!params[:invitations].nil? && !params[:invitations][:as_friendship].nil? ? true : false) %>
-		<label for="" title="<%= tooltip_title_attrib('Tick the checkbox to request friendship of new users after they join myExperiment<br/>or leave the checkbox blank to send plain invitation emails.') -%>"><%= check_box_tag "invitations[as_friendship]", "true", as_friendship_checked -%>Request friendships as well</label><br/>
+		<label for="" title="<%= tooltip_title_attrib("Tick the checkbox to request friendship of new users after they join #{Conf.sitename}<br/>or leave the checkbox blank to send plain invitation emails.") -%>"><%= check_box_tag "invitations[as_friendship]", "true", as_friendship_checked -%>Request friendships as well</label><br/>
 		
 		
 		<table style="margin-top: 2em;">
@@ -41,4 +41,4 @@
 		<input type="submit" id="cancel_button" value="Return to your Profile"  user_path(current_user) -%>';return false;" />
 	  
 	</p>
-<% end %>
\ No newline at end of file
+<% end %>

Modified: trunk/app/views/users/edit.rhtml (2115 => 2116)


--- trunk/app/views/users/edit.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/users/edit.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -20,7 +20,7 @@
 <br/>
 <h2>User Authentication</h2>
 <p style="text-align: center; line-height: 1.5;">
-    You have two options to log in: using a myExperiment username and password <b>OR</b> OpenID login details.
+    You have two options to log in: using a <%= Conf.sitename %> username and password <b>OR</b> OpenID login details.
     <br/>
     <i>Your account can have either of these or even both registered, as below.</i>
 </p>
@@ -28,7 +28,7 @@
 <table>
     <tr style="vertical-align: top;">
         <td style="width: 50%;">
-            <h2 style="width: 275px">myExperiment username / password</h2>
+            <h2 style="width: 275px"><%= Conf.sitename %> username / password</h2>
             <% form_for(:user, :url ="" user_path(@user), :html => { :method => :put }) do |f| %>
 						<%= hidden_field_tag(:update_type, "upd_t_up") -%>
             <center>
@@ -162,6 +162,6 @@
 <br/>
 <h2>Unregister</h2>
 <p>
-  If you would like to unregister from myExperiment, send us a message through the
-	<%= link_to "feedback form", :controller => "feedback", :action ="" "index", :subject => "Unregister from myExperiment" -%>.	
+  If you would like to unregister from <%= Conf.sitename %>, send us a message through the
+	<%= link_to "feedback form", :controller => "feedback", :action ="" "index", :subject => "Unregister from #{Conf.sitename}" -%>.	
 </p>

Modified: trunk/app/views/users/invite.rhtml (2115 => 2116)


--- trunk/app/views/users/invite.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/users/invite.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,5 +1 @@
-<% if logged_in? %>
-  <%= render :partial => "users/invite", :locals => { :current => current_user } -%>
-<% else %>
-  <p><strong><%= link_to "Log in", new_session_url %> to invite new users to myExperiment </strong></p>
-<% end %>
\ No newline at end of file
+<%= render :partial => "users/invite", :locals => { :current => current_user } -%>

Modified: trunk/app/views/users/new.rhtml (2115 => 2116)


--- trunk/app/views/users/new.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/users/new.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,6 +1,6 @@
 <% t "Register / Sign up" -%>
 
-<h1 style="margin-bottom: 1.3em;">Register for myExperiment</h1>
+<h1 style="margin-bottom: 1.3em;">Register for <%= Conf.sitename %></h1>
 
 <%= error_messages_for :user %>
 
@@ -9,14 +9,14 @@
 	You are responsible for any content that you upload. You may remove your content at any time. 
 	We may make copies for operational purposes. This service is governed by the 
 	<%= link_to "JANET Acceptable Use Policy", "http://www.ja.net/services/publications/policy/aup.html", :popup => true -%>. 
-	Takedown requests will be reviewed by the myExperiment Management Committee. 
-	We will take every care to preserve data but we will not be liable for loss or damage to data while it is stored within myExperiment. 
+	Takedown requests will be reviewed by the <%= Conf.sitename %> Management Committee. 
+	We will take every care to preserve data but we will not be liable for loss or damage to data while it is stored within <%= Conf.sitename %>. 
 	We receive and store certain types of information whenever you interact with us which we will 
-	use only for operational purposes and to support academic research into the use of myExperiment. 
+	use only for operational purposes and to support academic research into the use of <%= Conf.sitename %>. 
 	We will not make personally identifiable data available to third parties without consent. 
 	Please contact us if you have any queries about our terms or our privacy policy.
 	<br/><br/>
-	<strong>Please note: all user profiles are public on myExperiment.org</strong> and 
+	<strong>Please note: all user profiles are public on <%= Conf.sitename %></strong> and 
 	therefore can be viewed by anyone and be indexed by search engines such as Google.
 	However, usernames and registered email addresses (different to profile email addresses) are not exposed.
 </div> 
@@ -156,7 +156,7 @@
     </div>
     <div class="foldContent" style="display: block;">
 			<p class="box_infotext">
-				OpenID is a distributed identity system which gives you single sign-on anywhere that OpenID is supported. If you already have an OpenID you can enter it here and your myExperiment account will automatically be created (note that if you have an AOL or AIM account, or a LiveJournal or Wordpress blog, then you already have an OpenID).
+				OpenID is a distributed identity system which gives you single sign-on anywhere that OpenID is supported. If you already have an OpenID you can enter it here and your <%= Conf.sitename %> account will automatically be created (note that if you have an AOL or AIM account, or a LiveJournal or Wordpress blog, then you already have an OpenID).
 			</p>
 			
 			<p><b>Don't have an OpenID? Get one FREE from <%= link_to 'myOpenID', "https://www.myopenid.com/" %> or <%= link_to 'other providers', "http://openiddirectory.com/openid-providers-c-1.html" %>.</b></p>
@@ -171,4 +171,4 @@
 			</p>
 		</div>
 	</div>
-<% end %>
\ No newline at end of file
+<% end %>

Modified: trunk/app/views/users/timeline.rhtml (2115 => 2116)


--- trunk/app/views/users/timeline.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/users/timeline.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,4 +1,4 @@
-<h1>Timeline of Users joining myExperiment</h1>
+<h1>Timeline of Users joining <%= Conf.sitename %></h1>
 
 <%
   timeline = ::Simile::Timeline::Timeline.new(
@@ -36,4 +36,4 @@
 
 %>
 
-<%= simile_timeline(timeline, { :class => 'default_timeline' } ) %>
\ No newline at end of file
+<%= simile_timeline(timeline, { :class => 'default_timeline' } ) %>

Modified: trunk/app/views/workflows/_license.rhtml (2115 => 2116)


--- trunk/app/views/workflows/_license.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/workflows/_license.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -16,7 +16,7 @@
       <dc:title><%= contributor(workflow.contribution.contributor_id, workflow.contribution.contributor_type, link=false) %></dc:title>
    </Agent></dc:rights>
    <dc:type rdf:resource="http://purl.org/dc/dcmitype/Data" />
-   <dc:source rdf:resource="http://www.myexperiment.org<%= request.request_uri %>"/>
+   <dc:source rdf:resource="<%= Conf.base_uri %><%= request.request_uri %>"/>
    <license rdf:resource="http://creativecommons.org/licenses/by-nd/3.0/" />
 </Work>
 
@@ -50,7 +50,7 @@
       <dc:title><%= contributor(workflow.contribution.contributor_id, workflow.contribution.contributor_type, link=false) %></dc:title>
    </Agent></dc:rights>
    <dc:type rdf:resource="http://purl.org/dc/dcmitype/Data" />
-   <dc:source rdf:resource="http://www.myexperiment.org<%= request.request_uri %>"/>
+   <dc:source rdf:resource="<%= Conf.base_uri %><%= request.request_uri %>"/>
    <license rdf:resource="http://creativecommons.org/licenses/by-sa/3.0/" />
 </Work>
 
@@ -85,7 +85,7 @@
       <dc:title><%= contributor(workflow.contribution.contributor_id, workflow.contribution.contributor_type, link=false) %></dc:title>
    </Agent></dc:rights>
    <dc:type rdf:resource="http://purl.org/dc/dcmitype/Data" />
-   <dc:source rdf:resource="http://www.myexperiment.org<%= request.request_uri %>"/>
+   <dc:source rdf:resource="<%= Conf.base_uri %><%= request.request_uri %>"/>
    <license rdf:resource="http://creativecommons.org/licenses/by/3.0/" />
 </Work>
 
@@ -105,4 +105,4 @@
 
 <p>
   All versions of this Workflow are licensed under the <%= license_link workflow.license.to_s %>.
-</p>
\ No newline at end of file
+</p>

Modified: trunk/app/views/workflows/index.rxml (2115 => 2116)


--- trunk/app/views/workflows/index.rxml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/workflows/index.rxml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,11 +1,11 @@
 xml.rss "version" => "2.0", 'xmlns:opensearch' => "http://a9.com/-/spec/opensearch/1.1/", 'xmlns:atom' => "http://www.w3.org/2005/Atom" do
   xml.channel do
-    xml.title "myExperiment.org - Latest Workflows"
+    xml.title "#{Conf.sitename} - Latest Workflows"
     xml.link workflows_url
     xml.language "en-us"
     xml.ttl "60"
     xml.tag! "atom:link", :rel => 'search', :type => 'application/opensearchdescription+xml', :href ="" "http://#{request.host_with_port}/open_search.xml"
-    xml.description "RSS feed listing the latest Workflows which have been uploaded to myExperiment.org"
+    xml.description "RSS feed listing the latest Workflows which have been uploaded to #{Conf.sitename}"
     render(:partial => "layouts/workflow", :collection => @rss_workflows, :locals => { :xm => xml })
   end
-end
\ No newline at end of file
+end

Modified: trunk/app/views/workflows/new_version.rhtml (2115 => 2116)


--- trunk/app/views/workflows/new_version.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/workflows/new_version.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -19,7 +19,7 @@
 			<b>Note:</b> this new workflow version must be of the same type as the original one (so it must be a '<%= h(@workflow.type_display_name) -%>' workflow and have a <%= file_exts_allowed -%> file extension).
 		</p>
 		<p>
-			If you would like to upload a different type of workflow then <b><%= link_to "click here", new_workflow_path -%></b> to upload it as a new workflow entry in myExperiment.
+			If you would like to upload a different type of workflow then <b><%= link_to "click here", new_workflow_path -%></b> to upload it as a new workflow entry in <%= Conf.sitename %>.
 		</p>
 		<p>
 			Sharing, license and other settings are inherited from the parent workflow entry.

Modified: trunk/app/views/workflows/tag_suggestions.rhtml (2115 => 2116)


--- trunk/app/views/workflows/tag_suggestions.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/workflows/tag_suggestions.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -12,7 +12,7 @@
 </div>
 
 <p><em>Note: Tag suggestions are given by matching words in your workflow with other
-tags already used in myExperiment.</em></p>
+tags already used in <%= Conf.sitename %>.</em></p>
 
 <h2>Summary</h2>
 

Modified: trunk/app/views/workflows/taverna_scufl/_run_options.rhtml (2115 => 2116)


--- trunk/app/views/workflows/taverna_scufl/_run_options.rhtml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/views/workflows/taverna_scufl/_run_options.rhtml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -42,7 +42,7 @@
 			<p style="text-align: center; margin-top: 0.5em; font-size: 85%;">
 				If you are having problems downloading it in Taverna, you may need to provide your username and password in the URL so that Taverna can access the Workflow: <br/>
 				<% if logged_in? and current_user.username.nil? %>
-					First you need to <%= link_to 'register a username and password', edit_user_path(current_user) %> on your myExperiment account.
+					First you need to <%= link_to 'register a username and password', edit_user_path(current_user) %> on your <%= Conf.sitename %> account.
 				<% else %>
 					<b>Replace <font color="#990000">http://</font> in the link above with <font color="#990000">http://<%=(logged_in? and !current_user.username.nil?) ? h(current_user.username) : "yourusername" %>:yourpassword@</font></b>
 				<% end %>
@@ -58,12 +58,12 @@
 		</p>
 		
 		<h4>
-			<b>Run this Workflow through myExperiment</b>
+			<b>Run this Workflow through <%= Conf.sitename %></b>
 		</h4>
 		<div class="option_box">
 			<p style="font-size: 93%; text-align: center;">
 				<font style="color: #990000; font-weight: bold">Note:</font> 
-				you need to have access to a remote Taverna Execution Service in order to run Workflows through myExperiment. 
+				you need to have access to a remote Taverna Execution Service in order to run Workflows through <%= Conf.sitename %>. 
 				If you do, <%= link_to "register it as a 'Runner' here", new_runner_url -%>, then you can use it in Jobs to carry out the enactment. 
 				For more information, <%= link_to "contact us", "/feedback" -%>.
 			</p>
@@ -80,4 +80,4 @@
 		</div>
 	
 	<% end -%>
-</div>
\ No newline at end of file
+</div>

Modified: trunk/config/boot.rb (2115 => 2116)


--- trunk/config/boot.rb	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/config/boot.rb	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,5 +1,7 @@
 # Don't change this file. Configuration is done in config/environment.rb and config/environments/*.rb
 
+require 'lib/conf'
+
 RAILS_ROOT = "#{File.dirname(__FILE__)}/.." unless defined?(RAILS_ROOT)
 
 unless defined?(Rails::Initializer)

Modified: trunk/config/environment_private.rb.pre (2115 => 2116)


--- trunk/config/environment_private.rb.pre	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/config/environment_private.rb.pre	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1,6 +1,4 @@
 
-BASE_URI = "http://www.example.com"
-
 # Mailer configuration
 
 ActionMailer::Base.smtp_settings = {
@@ -33,10 +31,7 @@
 # server
 SOLR_ENABLE = false
 
-# Comma-seperated list of usernames (must be lowercase) of the users who are regarded as Admins.
-ADMINS = ["list", "of", "usernames"]
 
-
 # ---
 # BEGIN web analytics settings
 

Added: trunk/config/settings.yml.pre (0 => 2116)


--- trunk/config/settings.yml.pre	                        (rev 0)
+++ trunk/config/settings.yml.pre	2009-03-11 13:42:48 UTC (rev 2116)
@@ -0,0 +1,120 @@
+# myExperiment: config/settings.yml.pre
+#
+# Copyright (c) 2009 University of Manchester and the University of Southampton.
+# See license.txt for details.
+
+# ------------------------------------------------------------------------------
+#   myExperiment server configuration
+# ------------------------------------------------------------------------------
+#
+# site_name - Set "site_name" to the name of this myExperiment installation.
+#             This is used by the myExperiment codebase to refer to service by
+#             name.
+#
+#             Example:
+#
+#               site_name: mySite
+
+site_name: mySite
+
+# site_logo - set "site_logo" to the name of the logo used at the top left of
+#             the web pages.
+#
+#             Example:
+#
+#               site_logo: logo.png
+
+site_logo: logo.png
+
+# base_uri - Set "base_uri" to the main entry point to this installation of
+#            myExperiment.  If you use a load balancing solution to proxy
+#            incoming requests to a cluster, then this is the external address.
+#
+#            Examples:
+#
+#              base_uri: http://www.example.com
+#
+#            or
+#
+#              base_uri: http://www.example.com:3000
+#
+#            NOTE: No trailing slash.
+
+base_uri: http://www.example.com
+
+# admins - Set "admins" to the list of usernames of people that are
+#          administrators of this installation.  This is "Username" that is set
+#          when you manage your account, not the "Display Name".
+#
+#          Example:
+#
+#            admins: [dgc, jits, dtm]
+
+admins: []
+
+# main_tabs - These are the main tabs of the website.  Each entry requires at
+#             least a label and a link.  If you specify a controller in a tab,
+#             then the tab is shown as selected when the page has been served by
+#             a controller that matches.
+#
+#             The controller entry is a regular _expression_, so you can make a tab
+#             show as selected in multiple controllers.
+#
+#             Example:
+#
+#               main_tabs:
+#
+#                 - label:      Home
+#                   link:       /home
+#                   controller: home
+#
+#                 - label:      Users
+#                   link:       /users
+#                   controller: (users|profiles|userhistory|friendships|memberships|pictures)
+#
+#                 - label:      Groups
+#                   link:       /groups
+#                   controller: networks
+#
+#                 - label:      Wiki
+#                   link:       http://wiki.example.com/
+
+main_tabs:
+
+  - label:      Home
+    link:       /home
+    controller: home
+
+  - label:      Users
+    link:       /users
+    controller: (users|profiles|userhistory|friendships|memberships|pictures)
+
+  - label:      Groups
+    link:       /groups
+    controller: networks
+
+  - label:      Workflows
+    link:       /workflows
+    controller: workflows
+
+  - label:      Files
+    link:       /files
+    controller: blobs
+
+  - label:      Packs
+    link:       /packs
+    controller: packs
+
+# email - These are the email addresses used for sending notifications and the
+#         email address to send feedback entered from the web site.
+#
+#         Example:
+#
+#           notifications_email_address: address@hidden
+#
+#           feedback_email_address: address@hidden
+
+notifications_email_address: address@hidden
+
+feedback_email_address: address@hidden
+

Modified: trunk/lib/rest.rb (2115 => 2116)


--- trunk/lib/rest.rb	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/lib/rest.rb	2009-03-11 13:42:48 UTC (rev 2116)
@@ -50,161 +50,168 @@
   "#{request.protocol}#{request.host_with_port}#{path}"
 end
 
-def rest_get_request(ob, req_uri, user, uri, entity_name, query)
+def rest_get_element(ob, user, rest_entity, rest_attribute, query)
 
-  if query['version']
-    return rest_error_response(400, 'Resource not versioned') unless ob.respond_to?('versions')
-    return rest_error_response(404, 'Resource version not found') if query['version'].to_i < 1
-    return rest_error_response(404, 'Resource version not found') if ob.versions[query['version'].to_i - 1].nil?
-  end
+  model_data = TABLES['Model'][:data][rest_entity]
 
-  elements = query['elements'] ? query['elements'].split(',') : nil
+  i = model_data['REST Attribute'].index(rest_attribute)
 
-  doc  = XML::Document.new()
-  root = XML::Node.new(entity_name)
-  doc.root = root
+  # is this attributed limited to a particular user?
 
-  root['uri'        ] = rest_access_uri(ob)
-  root['resource'   ] = uri if uri
-  root['api-version'] = API_VERSION if query['api_version'] == 'yes'
+  limited_to_user = model_data['Limited to user'][i]
 
-  if ob.respond_to?('versions')
-    if query['version']
-      root['version'] = query['version']
+  if not limited_to_user.nil?
+    if limited_to_user == 'self'
+      limited_ob = ob
     else
-      root['version'] = ob.versions.last.version.to_s
+      limited_ob = eval("ob.#{limited_to_user}")
     end
+
+    return nil if limited_ob != user
   end
 
-  data = ""
+  unless query['all_elements'] == 'yes'
+    return nil if elements and not elements.index(model_data['REST Attribute'][i])
+    return nil if not elements and model_data['Read by default'][i] == 'no'
+  end
 
-  rest_entity = data['REST Entity']
+  if (model_data['Read'][i] == 'yes')
 
-  model_data = TABLES['Model'][:data][rest_entity]
+    accessor = model_data['Accessor'][i]
 
-  (0...model_data['REST Attribute'].length).each do |i|
+    text  = ''
+    attrs = {}
 
-    # is this attributed limited to a particular user?
+    case model_data['Encoding'][i]
 
-    limited_to_user = model_data['Limited to user'][i]
+      when 'list'
 
-    if not limited_to_user.nil?
-      if limited_to_user == 'self'
-        limited_ob = ob
-      else
-        limited_ob = eval("ob.#{limited_to_user}")
-      end
+        list_element = XML::Node.new(model_data['REST Attribute'][i])
 
-      next if limited_ob != user
-    end
+        attrs.each do |key,value|
+          list_element[key] = value
+        end
 
-    unless query['all_elements'] == 'yes'
-      next if elements and not elements.index(model_data['REST Attribute'][i])
-      next if not elements and model_data['Read by default'][i] == 'no'
-    end
+        collection = eval("ob.#{model_data['Accessor'][i]}")
 
-    if (model_data['Read'][i] == 'yes')
+        # filter out things that the user cannot see
+        collection = collection.select do |c|
+          not c.respond_to?('contribution') or Authorization.is_authorized?("view", nil, c, user)
+        end
 
-      accessor = model_data['Accessor'][i]
+        collection.each do |item|
 
-      text  = ''
-      attrs = {}
+          item_attrs = { }
 
-      case model_data['Encoding'][i]
+          item_uri = rest_resource_uri(item)
+          item_attrs['resource'] = item_uri if item_uri
+          item_attrs['uri'] = rest_access_uri(item)
 
-        when 'list'
+          list_element_accessor = model_data['List Element Accessor'][i]
+          list_element_text     = list_element_accessor ? eval("item.#{model_data['List Element Accessor'][i]}") : item
 
-          list_element = XML::Node.new(model_data['REST Attribute'][i])
+          if list_element_text.instance_of?(String)
+            el = XML::Node.new(model_data['List Element Name'][i])
 
-          attrs.each do |key,value|
-            list_element[key] = value
-          end
+            item_attrs.each do |key,value|
+              el[key] = value
+            end
 
-          root << list_element
+            el << list_element_text.to_s if list_element_text
 
-          collection = eval("ob.#{model_data['Accessor'][i]}")
-
-          # filter out things that the user cannot see
-          collection = collection.select do |c|
-            not c.respond_to?('contribution') or Authorization.is_authorized?("view", nil, c, user)
+            list_element << el
+          else
+            list_element << rest_reference(list_element_text, query)
           end
+        end
 
-          collection.each do |item|
+        list_element
 
-            item_attrs = { }
+      when 'xml'
 
-            item_uri = rest_resource_uri(item)
-            item_attrs['resource'] = item_uri if item_uri
-            item_attrs['uri'] = rest_access_uri(item)
+        if query['version'] and model_data['Versioned'][i] == 'yes'
+          text = eval("ob.versions[#{(query['version'].to_i - 1).to_s}].#{accessor}")
+        else
+          text = eval("ob.#{accessor}")
+        end
 
-            list_element_accessor = model_data['List Element Accessor'][i]
-            list_element_text     = list_element_accessor ? eval("item.#{model_data['List Element Accessor'][i]}") : item
+        text
 
-            if list_element_text.instance_of?(String)
-              el = XML::Node.new(model_data['List Element Name'][i])
+      else 
 
-              item_attrs.each do |key,value|
-                el[key] = value
-              end
+        if model_data['Encoding'][i] == 'file-column'
 
-              el << list_element_text.to_s if list_element_text
+          text = file_column_url(ob, model_data['Accessor'][i])
 
-              list_element << el
+        else
+
+          if accessor
+            if query['version'] and model_data['Versioned'][i] == 'yes'
+              text = eval("ob.versions[#{(query['version'].to_i - 1).to_s}].#{accessor}").to_s
             else
-              list_element << rest_reference(list_element_text, query)
+              text = eval("ob.#{accessor}").to_s
             end
           end
 
-        when 'xml'
+          if (model_data['Encoding'][i] == 'base64')
+            text = Base64.encode64(text)
+            attrs = { 'type' => 'binary', 'encoding' => 'base64' }
+          end
 
-          if query['version'] and model_data['Versioned'][i] == 'yes'
-            text = eval("ob.versions[#{(query['version'].to_i - 1).to_s}].#{accessor}")
-          else
-            text = eval("ob.#{accessor}")
+          if model_data['Foreign Accessor'][i]
+            resource_uri = eval("rest_resource_uri(ob.#{model_data['Foreign Accessor'][i]})")
+            attrs['resource'] = resource_uri if resource_uri
+            attrs['uri'] = eval("rest_access_uri(ob.#{model_data['Foreign Accessor'][i]})")
           end
+        end
 
-          root << text
+        # puts "ATTRIBUTE = #{model_data['REST Attribute'][i]}, ATTRS = #{attrs.inspect}, text = #{text.inspect}"
 
-        else 
+        el = XML::Node.new(model_data['REST Attribute'][i])
 
-          if model_data['Encoding'][i] == 'file-column'
+        attrs.each do |key,value|
+          el[key] = value if value
+        end
 
-            text = file_column_url(ob, model_data['Accessor'][i])
+        el << text
+        el
+    end
+  end
+end
 
-          else
+def rest_get_request(ob, req_uri, user, uri, entity_name, query)
 
-            if accessor
-              if query['version'] and model_data['Versioned'][i] == 'yes'
-                text = eval("ob.versions[#{(query['version'].to_i - 1).to_s}].#{accessor}").to_s
-              else
-                text = eval("ob.#{accessor}").to_s
-              end
-            end
+  if query['version']
+    return rest_error_response(400, 'Resource not versioned') unless ob.respond_to?('versions')
+    return rest_error_response(404, 'Resource version not found') if query['version'].to_i < 1
+    return rest_error_response(404, 'Resource version not found') if ob.versions[query['version'].to_i - 1].nil?
+  end
 
-            if (model_data['Encoding'][i] == 'base64')
-              text = Base64.encode64(text)
-              attrs = { 'type' => 'binary', 'encoding' => 'base64' }
-            end
+  elements = query['elements'] ? query['elements'].split(',') : nil
 
-            if model_data['Foreign Accessor'][i]
-              resource_uri = eval("rest_resource_uri(ob.#{model_data['Foreign Accessor'][i]})")
-              attrs['resource'] = resource_uri if resource_uri
-              attrs['uri'] = eval("rest_access_uri(ob.#{model_data['Foreign Accessor'][i]})")
-            end
-          end
+  doc  = XML::Document.new()
+  root = XML::Node.new(entity_name)
+  doc.root = root
 
-  #        puts "ATTRIBUTE = #{model_data['REST Attribute'][i]}, ATTRS = #{attrs.inspect}, text = #{text.inspect}"
+  root['uri'        ] = rest_access_uri(ob)
+  root['resource'   ] = uri if uri
+  root['api-version'] = API_VERSION if query['api_version'] == 'yes'
 
-          el = XML::Node.new(model_data['REST Attribute'][i])
+  if ob.respond_to?('versions')
+    if query['version']
+      root['version'] = query['version']
+    else
+      root['version'] = ob.versions.last.version.to_s
+    end
+  end
 
-          attrs.each do |key,value|
-            el[key] = value if value
-          end
+  data = ""
 
-          el << text
-          root << el
-      end
-    end
+  rest_entity = data['REST Entity']
+
+  TABLES['Model'][:data][rest_entity]['REST Attribute'].each do |rest_attribute|
+    data = "" user, rest_entity, rest_attribute, query)
+    root << data unless data.nil?
   end
 
   doc

Modified: trunk/lib/sanity_test.rb (2115 => 2116)


--- trunk/lib/sanity_test.rb	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/lib/sanity_test.rb	2009-03-11 13:42:48 UTC (rev 2116)
@@ -56,11 +56,10 @@
   workflows     = Workflow.find(:all)
   blogs         = Blog.find(:all)
   blobs         = Blob.find(:all)
-  forums        = Forum.find(:all)
   packs         = Pack.find(:all)
   contributions = Contribution.find(:all)
 
-  known_contributables = workflows + blobs + blogs + forums + packs
+  known_contributables = workflows + blobs + blogs + packs
 
   should_be_empty("All users must have a name",
       users.select do |u| u.name == nil or u.name.length == 0 end)
@@ -79,9 +78,6 @@
   should_be_empty("All blogs must have a contribution record",
       blogs.select do |b| b.contribution.nil? end)
 
-  should_be_empty("All forums must have a contribution record",
-      forums.select do |f| f.contribution.nil? end)
-
   should_be_empty("All packs must have a contribution record",
       packs.select do |f| f.contribution.nil? end)
 
@@ -93,12 +89,6 @@
 
   # workflows
 
-  should_all_be_true("All workflow image files must exist",
-      workflows.map do |w| File.exists?(w.image) end)
-
-  should_all_be_true("All workflow svg files must exist",
-      workflows.map do |w| File.exists?(w.svg) end)
-
   should_be_empty("All workflows must have a content type",
       workflows.select do |w| w.content_type.length.zero? end)
 

Modified: trunk/lib/whip.rb (2115 => 2116)


--- trunk/lib/whip.rb	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/lib/whip.rb	2009-03-11 13:42:48 UTC (rev 2116)
@@ -16,11 +16,11 @@
 	SchemeDataType = "http://org.whipplugin/data/description/datatype"
 	SchemeEntryPoint = "http://org.whipplugin/data/description/entrypoint"
 	TermInstaller = "urn:org.whipplugin:data:description:installer"
-	SchemeWorkflowID = "http://www.myexperiment.org/workflows/workflowid"
-	SchemeVersion = "http://www.myexperiment.org/workflows/version"
+	SchemeWorkflowID = "#{Conf.base_uri}/workflows/workflowid"
+	SchemeVersion = "#{Conf.base_uri}/workflows/version"
 	# datatype used to identify Taverna 1.7 compatible scufl
 	Taverna1DataType = "http://org.embl.ebi.escience/xscufl/0.1alpha"
-	EntryIDPrefix = "http://www.myexperiment.org/workflows/"
+	EntryIDPrefix = "#{Conf.base_uri}/workflows/"
 	AtomDateFormat = "%Y-%m-%dT%H:%M:%SZ"
 	
 	# 

Modified: trunk/test/fixtures/users.yml (2115 => 2116)


--- trunk/test/fixtures/users.yml	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/test/fixtures/users.yml	2009-03-11 13:42:48 UTC (rev 2116)
@@ -2,6 +2,8 @@
 
 <% SALT = "NaCl" unless defined?(SALT) %>
 
+<% Conf.admins = ['adam'] %>
+
 john:
   id: 1
   openid_url:
@@ -30,7 +32,7 @@
   id: 3
   openid_url:
   name: Adam Ministrator
-  username: <%= ADMINS[0] %>
+  username: adam
   salt: <%= SALT %>
   crypted_password: <%= User.encrypt('secret', SALT) %>
   email: address@hidden

reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- trunk/app/controllers/session_controller.rb	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/controllers/session_controller.rb	2009-03-11 13:42:48 UTC (rev 2116)
@@ -32,7 +32,7 @@
     self.current_user.forget_me if logged_in?
     cookies.delete :auth_token
     reset_session # clears session[:return_to]
     #flash[:notice] = "You have been logged out. Thank you for using myExperiment!"
     redirect_to ''
   end
   
@@ -124,7 +124,7 @@
       # update "last seen" attribute
       user.update_attribute(:last_seen_at, Time.now)
       respond_to do |format|
-        flash[:notice] = "Logged in successfully. Welcome to myExperiment!"
+        flash[:notice] = "Logged in successfully. Welcome to #{Conf.sitename}!"
         home_url = url_for(:controller => 'home')
         format.html { session[:return_to] and URI.parse(session[:return_to]).path == '/' ? redirect_to(home_url) : redirect_back_or_default(home_url) }
       end
@@ -32,7 +32,7 @@
     cookies.delete :auth_token
     reset_session # clears session[:return_to]
-    #flash[:notice] = "You have been logged out. Thank you for using myExperiment!"
+    #flash[:notice] = "You have been logged out. Thank you for using #{Conf.sitename}!"
     redirect_to ''
   end

Modified: trunk/app/controllers/users_controller.rb (2115 => 2116)


--- trunk/app/helpers/application_helper.rb	2009-03-06 15:58:46 UTC (rev 2115)
+++ trunk/app/helpers/application_helper.rb	2009-03-11 13:42:48 UTC (rev 2116)
@@ -1311,8 +1311,8 @@
     
     text += "<p>
               Note that updating privileges only affect how other users can update this
-              #{visible_type} entry on myExperiment. If the user downloads the #{resource},
-              they can still edit it away from myExperiment and possible upload it back as a new entry.
+              #{visible_type} entry on #{Conf.sitename}. If the user downloads the #{resource},
+              they can still edit it away from #{Conf.sitename} and possible upload it back as a new entry.
             </p>"
             
     return text
@@ -1417,7 +1417,7 @@
         return rtn unless (restrict_contributor.class.to_s == "User" and item.id.to_i == restrict_contributor.id.to_i)
       end
       
-      rtn << [item.created_at, "#{name(item)} joined #{link_to "myExperiment", "/"}."]
+      rtn << [item.created_at, "#{name(item)} joined #{link_to Conf.sitename, "/"}."]
     when "Contribution"
       return rtn if before and item.created_at > before
       return rtn if after and item.created_at < after

Modified: trunk/app/models/contribution.rb (2115 => 2116)

